@@ -1,4 +1,4 @@
-from .API import ScreenScrapper
+from .API import ScreenScraper
 from .ScreenManager import ScreenManager
 from .InputController import InputController
 from .screen_grabber import grab_screen
